<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

/**
 * Payment functions.
 *
 * This file holds all the payment related functions.
 *
 * @author        Jeroen Sormani
 * @since         1.0.0
 */


/**
 * Create a payment.
 *
 * Create a new payment when someone clicks the pay button.
 *
 * @since 1.0.0
 *
 * @param  array $data List of payment arguments.
 *
 * @return int         Post ID of the created payment.
 */
function pt_create_payment( $data ) {

	$data = wp_parse_args( $data, array (
		'payment_id'   => '',
		'mode'         => '',
		'amount'       => '0',
		'description'  => '',
		'status'       => 'open',
		'order_status' => 'new',
		'method'       => '',
	) );

	$data = apply_filters( 'pt_create_payment_arguments', $data );

	$post_id = wp_insert_post( array (
		'post_title'  => '',
		'post_type'   => 'pt_payment',
		'post_status' => 'publish',
	) );

	// Insert payment data as post meta
	foreach ( $data as $key => $value ) {

		// Don't store serialized meta information
		if ( $key == 'meta' ) {
			continue;
		};

		add_post_meta( $post_id, '_' . $key, $value );
	}

	// Store all fields as post meta
	foreach ( $data['meta'] as $key => $value ) {

		// Make sure a checkbox with multiple selected values is stored as a string
		// See: https://github.com/davdebcom/paytium/issues/199
		if ( ( strpos( $key, '-checkbox-' ) ) && ( strpos( $key, '-label' ) == false ) ) {
			$value = implode( ', ', maybe_unserialize( $value ) );
		}

		add_post_meta( $post_id, '_' . $key, $value );
	}

	return $post_id;

}


/**
 * Update a payment.
 *
 * Update a new payment after payment sent to Mollie API.
 *
 * @since 1.0.0
 *
 * @param  array $meta List of payment arguments.
 *
 * @return int         true
 */
function pt_update_payment_meta( $post_id, $meta ) {

	if ( ! get_post( $post_id ) || ! is_array( $meta ) || empty( $meta ) ) {
		return false;
	}

	foreach ( $meta as $meta_key => $meta_value ) {
		update_post_meta( $post_id, '_' . $meta_key, $meta_value );
	}

	return true;

}


/**
 * Get payment.
 *
 * Get a single PT_Payment object.
 *
 * @since 1.0.0
 *
 * @param  int $post_id Post ID of the payment to get.
 *
 * @return PT_Payment|bool          PT_Payment object when its a valid post ID, or false when not found.
 */
function pt_get_payment( $post_id ) {

	$payment = new PT_Payment( $post_id );

	if ( empty( $payment ) ) :
		$payment = false;
	endif;

	return apply_filters( 'pt_get_payment', $payment, $post_id );

}


/**
 * Get payment by payment ID.
 *
 * Get a single PT_Payment object based on the payment ID provided by Mollie.
 *
 * @since 1.0.0
 *
 * @param  string $payment_id Payment ID to get the pt_payment form.
 *
 * @return mixed              PT_Payment object when its a valid post ID, or false when not found.
 */
function pt_get_payment_by_payment_id( $payment_id ) {

	global $wpdb;

	$post_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM {$wpdb->postmeta} WHERE meta_value = %s AND meta_key = '_payment_id'", $payment_id ) );

	// TODO: If payment not found in database, check if it belongs to a previous subscription based on subscriptionId

	if ( $post_id == null ) {
		return null;
	}

	// TODO: what if no corresponding payment is found at all? But, received payment_id from Mollie right? Should always be there?

	return pt_get_payment( $post_id );

}

/**
 * Get payment by payment key.
 *
 * Get a single PT_Payment object based on the payment key (generated by Paytium, used in redirectURL).
 *
 * @since 1.0.0
 *
 * @param  string $payment_key Key to get the pt_payment form.
 *
 * @return PT_Payment               PT_Payment object when its a valid post ID, or false when not found.
 */
function pt_get_payment_by_payment_key( $payment_key ) {

	global $wpdb;

	$post_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM {$wpdb->postmeta} WHERE meta_value = %s AND meta_key = '_payment_key'", $payment_key ) );

	return pt_get_payment( $post_id );

}

/**
 * Try getting payment by subscription ID.
 *
 * Get a single PT_Payment object based on the subscription ID if provided by Mollie.
 *
 * @since 1.3.0
 *
 * @param  string $subscription_id Subscription ID to get the pt_payment form.
 *
 * @return mixed                    PT_Payment object when its a valid post ID, or false when not found.
 */
function pt_get_payment_by_subscription_id( $subscription_id ) {

	global $wpdb;

	if ( $subscription_id == null ) {
		return null;
	}

	// Find the first payment in database (search old to new) with the subscription ID
	$post_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM {$wpdb->postmeta} WHERE meta_value = %s AND meta_key = '_subscription_id'", $subscription_id ) );

	if ( $post_id == null ) {
		return null;
	}

	return pt_get_payment( $post_id );

}

/**
 * Get payment statuses.
 *
 * Get a list of the available payment statuses.
 *
 * @since 1.0.0
 *
 * @return array List of payment statuses.
 */
function pt_get_payment_statuses() {

	$statuses = apply_filters( 'pt_payment_statuses', array (
		'open'         => __( 'Open', 'paytium' ),
		'cancelled'    => __( 'Cancelled', 'paytium' ),
		'expired'      => __( 'Expired', 'paytium' ),
		'failed'       => __( 'Failed', 'paytium' ),
		'paid'         => __( 'Paid', 'paytium' ),
		'refunded'     => __( 'Refunded', 'paytium' ),
		'charged_back' => __( 'Chargeback', 'paytium' ),
	) );

	return $statuses;

}


/**
 * Get order statuses.
 *
 * Get a list of the available order statuses.
 * An order status is different then a payment status.
 *
 * @since 1.0.0
 *
 * @return array List of payment statuses.
 */
function pt_get_order_statuses() {

	$statuses = apply_filters( 'pt_order_statuses', array (
		'new'        => __( 'New', 'paytium' ),
		'processing' => __( 'Processing', 'paytium' ),
		'completed'  => __( 'Completed', 'paytium' ),
	) );

	return $statuses;

}


/**
 * Get payment methods.
 *
 * Get a list of the available payment methods in a slug => name pair.
 *
 * @since 1.0.0
 *
 * @return array List of payment methods.
 */
function pt_get_payment_methods() {

	$payment_methods = apply_filters( 'pt_payment_methods', array (
		'ideal'             => __( 'iDEAL', 'paytium' ),
		'creditcard'        => __( 'Credit Card', 'paytium' ),
		'sofort'            => __( 'SOFORT', 'paytium' ),
		'mistercash'        => __( 'Mister Cash', 'paytium' ),
		'banktransfer'      => __( 'Bank transfer', 'paytium' ),
		'directdebit'       => __( 'SEPA Direct Debit', 'paytium' ),
		'belfius'           => __( 'Belfius', 'paytium' ),
		'paypal'            => __( 'PayPal', 'paytium' ),
		'bitcoin'           => __( 'Bitcoin', 'paytium' ),
		'podiumcadeaukaart' => __( 'PODIUM Cadeaukaart', 'paytium' ),
		'paysafecard'       => __( 'paysafecard', 'paytium' ),
		'kbc'               => __( 'KBC/CBC Payment Button', 'paytium' ),
		'inghomepay'        => __( 'ING Home\'Pay', 'paytium' ),
		'giftcard'          => __( 'Cadeaukaarten', 'paytium' )
	) );

	return $payment_methods;

}

/**
 * Get customer ID by customer email.
 *
 * Get a single PT_Payment object based on the payment ID provided by Mollie.
 *
 * @since 1.0.0
 *
 * @param  string $payment_id Payment ID to get the pt_payment form.
 *
 * @return mixed              PT_Payment object when its a valid post ID, or false when not found.
 */
function pt_get_customer_by_email_in_paytium( $customer_email ) {

	global $wpdb;

	// If post_id not found, return
	$post_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key = '_pt-customer-email' AND meta_value = %s ORDER BY post_id DESC LIMIT 1 ", $customer_email ) );

	// If post_id found, search for the customer ID
	$customer_id = $wpdb->get_var( $wpdb->prepare( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = %s AND meta_key = '_pt-customer-id' ORDER BY post_id DESC LIMIT 1", $post_id ) );


	return $customer_id;

}

/**
 * Copy field data from postmeta of one payment and copy to other
 *
 * @since 1.3.0
 *
 * @return string
 */

function pt_copy_field_data( $meta ) {

	$field_data = array ();

	foreach ( $meta as $key => $value ) {

		// Add fields to custom data
		// Note: Every field has only one label, but two postmeta items in DB
		if ( strstr( $key, 'pt-field' ) ) {
			// Update key/label for fields with user defined label
			$field_data[ $key ] = $value[0];
		}

	}

	return $field_data;

}


/**
 * WP Ajax function to cancel a Mollie subscription
 *
 * @since 1.4.0
 *
 * @return mixed
 */

function pt_cancel_subscription() {

	global $pt_mollie;

	try {

		$payment_id = isset( $_REQUEST['payment_id'] ) ? $_REQUEST['payment_id'] : '';
		$subscription_id = isset( $_REQUEST['subscription_id'] ) ? $_REQUEST['subscription_id'] : '';
		$customer_id     = isset( $_REQUEST['customer_id'] ) ? $_REQUEST['customer_id'] : '';

		$payment = pt_get_payment( $payment_id );
		pt_set_paytium_key( $payment->mode );

		$subscription = $pt_mollie->customers_subscriptions->withParentId( $customer_id )->cancel( $subscription_id );;

		// Update subscription in database
		$new_details = array (
			'subscription_cancelled_date' => preg_replace( '/T.*/', '', $subscription->cancelledDatetime ),
			'subscription_status'         => $subscription->status,
		);
		pt_update_payment_meta( $payment->id, $new_details );

		// Send response details to javascript for AJAX processing
		$response = array (
			'success' => true,
			'status' => ucfirst( $subscription->status ),
			'time' => preg_replace( '/T.*/', '', $subscription->cancelledDatetime )
		);
		wp_send_json( $response );

	}
	catch ( Mollie_API_Exception $e ) {
		error_log( 'Paytium: showing subscription metabox error: ' . htmlspecialchars( $e->getMessage() ) );
		wp_send_json_error();
	}

	wp_die();
}

add_action( 'wp_ajax_pt_cancel_subscription', 'pt_cancel_subscription' );
